Changeset: 782886fe543b for MonetDB
URL: http://dev.monetdb.org/hg/MonetDB?cmd=changeset;node=782886fe543b
Modified Files:
        monetdb5/mal/mal_type.c
Branch: Dec2011
Log Message:

isAmbigous: also flag bte type

bte also needs explicit :bte when serialised, since it doesn't equal :int


diffs (20 lines):

diff --git a/monetdb5/mal/mal_type.c b/monetdb5/mal/mal_type.c
--- a/monetdb5/mal/mal_type.c
+++ b/monetdb5/mal/mal_type.c
@@ -209,14 +209,14 @@ getTypeIndex(str nme, int len, int defty
 /*
  * @-
  * Literal constants are not necessary type specific, e.g.
  * the value '0' could represent sht,wrd,int,lng.
  * If the value is potential ambiguous then it should
  * be made type specific in listings
  */
 int
 isAmbiguousType(int type){
        switch(type){
-       case TYPE_sht: case TYPE_wrd: case TYPE_int: case TYPE_lng:
+               case TYPE_bte: case TYPE_sht: case TYPE_wrd: case TYPE_int: 
case TYPE_lng:
                return type != TYPE_int;
        }
@@ -209,14 +209,14 @@ getTypeIndex(str nme, int len, int defty
  * @-
  * Literal constants are not necessary type specific, e.g.
- * the value '0' could represent sht,wrd,int,lng.
+ * the value '0' could represent bte,sht,wrd,int,lng.
  * If the value is potential ambiguous then it should
  * be made type specific in listings
        return 0;
_______________________________________________
Checkin-list mailing list
Checkin-list@monetdb.org
http://mail.monetdb.org/mailman/listinfo/checkin-list

Reply via email to